﻿using System;
using System.ComponentModel;
using System.Text;
using System.Windows.Forms;
using H1xSDK;

namespace ScanBarcodeAppl
{
    public partial class Form1 : Form
    {
        BarcodeDevice barcodeDevice = new BarcodeDevice();
        ScanBarcode scanBarcode = new ScanBarcode();
        byte[] barcodeBuffer = new byte[4096];

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Enable the barcode device
            if (!barcodeDevice.BarcodeReaderEnabled)
                barcodeDevice.BarcodeReaderEnabled = true;

            // Set to no suffix
            barcodeDevice.SetOptions("RZ", BarcodeDevice.MaskOptions.STRING);

            // Handle the trigger and barcode data by the application
            barcodeDevice.KeyboardHook = false;

            scanBarcode.BarcodeDataReceived += new ScanBarcode.BarcodeDataReceivedEventHandler(scanBarcode_BarcodeDataReceived);

        }

        private void Form1_Closing(object sender, CancelEventArgs e)
        {
            // Cleanup the used resources
            scanBarcode.Dispose();
            barcodeDevice.Dispose();
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Return:       // Return or Action key
                case (Keys)0xF4:        // Dedicated scan button key code
                    barcodeDevice.TriggerPress();
                    // Set that the pressed key is already handled
                    // the framework does not need to handle it anymore
                    e.Handled = true;
                    break;
            }
        }

        private void Form1_KeyUp(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Return:       // Return or Action key
                case (Keys)0xF4:        // Dedicated scan button key code
                    barcodeDevice.TriggerRelease();
                    // Set that the Released key is already handled
                    // the framework does not need to handle it anymore
                    e.Handled = true;
                    break;
            }
        }

        void scanBarcode_BarcodeDataReceived()
        {
            // Read the scanned barcode data
            int dataLength = scanBarcode.ReadBarcodeData(barcodeBuffer);

            // Convert the barcode data to a string and put it in the textbox
            ASCIIEncoding enc = new ASCIIEncoding();
            String str = enc.GetString(barcodeBuffer, 0, dataLength);
            textBoxBarcode.Text = str; 
        }
    }
}