﻿using System;
using System.ComponentModel;
using System.Drawing;
using System.Windows.Forms;
using H1xSDK;

namespace TakePicture
{
    public partial class Form1 : Form
    {
        BarcodeDevice barcodeDevice = new BarcodeDevice();
        CaptureImage captureImage = new CaptureImage();

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            captureImage.ImageProgress += new CaptureImage.ImageProgressEventHandler(captureImage_ImageProgress);
            captureImage.ImageDownloadStatus += new CaptureImage.ImageDownloadStatusEventHandler(captureImage_ImageDownloadStatus);
            captureImage.ImageError += new CaptureImage.ImageErrorEventHandler(captureImage_ImageError);

            // Disable the Keyboardhook
            barcodeDevice.KeyboardHook = false;

            // Set some of the image properties
            menuItemRotate.Checked = captureImage.Rotate;
            menuItemAiming.Checked = captureImage.UseAimLed;

            cmboImageFormat.SelectedIndex = 0;  // JPG
            cmboJpgQuality.SelectedIndex = 8;   // JPG quality 60%
            cmboResolution.SelectedIndex = 0;   // Full resolution
            cmboBPP.SelectedIndex = 2;          // 8 bits per pixel

            Rectangle imgRect = new Rectangle(0, 0, 1279, 1023);
            captureImage.ImageWindow = imgRect;

        }

        private void Form1_Closing(object sender, CancelEventArgs e)
        {
            // cleanup the resources
            barcodeDevice.Dispose();
            captureImage.Dispose();
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Return:   // The return or Action key
                case (Keys)0xF4:
                    barcodeDevice.TriggerPress();
                    e.Handled = true;
                    break;
            }
        }

        private void Form1_KeyUp(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Return:   // The return or Action key
                case (Keys)0xF4:
                    barcodeDevice.TriggerRelease();
                    e.Handled = true;
                    break;
            }
        }

        void captureImage_ImageProgress(int percentage)
        {
            progressBar1.Value = percentage;
        }

        void captureImage_ImageDownloadStatus(CaptureImage.ImageDownStat downStatus)
        {
            this.Text = downStatus.ToString();
            if (downStatus == CaptureImage.ImageDownStat.IMAGE_DWN_FILE_SAVED)
            {
                if( captureImage.FileFormat == CaptureImage.ImageFormat.FM_JPG )
                    pictureBox1.Image = new System.Drawing.Bitmap("\\My Documents\\My pictures\\MyImage.JPG");
                else if (captureImage.FileFormat == CaptureImage.ImageFormat.FM_BMP)
                    pictureBox1.Image = new System.Drawing.Bitmap("\\My Documents\\My pictures\\MyImage.BMP");
                else
                    pictureBox1.Image = new System.Drawing.Bitmap("\\My Documents\\My pictures\\MyImage.TIFF");
            }
        }

        void captureImage_ImageError(ReturnValues imageError)
        {
            MessageBox.Show(imageError.ToString());
        }

        private void button1_Click(object sender, EventArgs e)
        {
            ReturnValues retValue;

            // Set the image file format
            switch (cmboImageFormat.SelectedIndex)
            {
                case 0:
                    captureImage.FileFormat = CaptureImage.ImageFormat.FM_JPG;
                    break;
                case 1:
                    captureImage.FileFormat = CaptureImage.ImageFormat.FM_BMP;
                    break;
                case 2:
                    captureImage.FileFormat = CaptureImage.ImageFormat.FM_TIFF;
                    break;

            }
           
            // Set the JPG image quality
            captureImage.JPGQuality = Convert.ToUInt32(cmboJpgQuality.SelectedItem.ToString());

            // Set the used bits per pixel
            switch (cmboBPP.SelectedIndex)
            {
                case 0:
                    captureImage.BitsPerPixel = CaptureImage.BitsPerPix.BPP_1;
                    break;
                case 1:
                    captureImage.BitsPerPixel = CaptureImage.BitsPerPix.BPP_4;
                    break;
                case 2:
                    captureImage.BitsPerPixel = CaptureImage.BitsPerPix.BPP_8;
                    break;
            }

            // set the selected resolution
            switch (cmboResolution.SelectedIndex)
            {
                case 0:
                    captureImage.Resolution = CaptureImage.Resolutions.RES_FULL;
                    break;
                case 1:
                    captureImage.Resolution = CaptureImage.Resolutions.RES_1_4;
                    break;
                case 2:
                    captureImage.Resolution = CaptureImage.Resolutions.RES_1_9;
                    break;
                case 3:
                    captureImage.Resolution = CaptureImage.Resolutions.RES_1_16;
                    break;
            }

            // Take the picture 
            retValue = captureImage.TakeSnapShot("\\My documents\\My Pictures", "MyImage");
            if (retValue != ReturnValues.SUCCESS)
                MessageBox.Show(retValue.ToString());
        }

        private void menuItemRotate_Click(object sender, EventArgs e)
        {
            menuItemRotate.Checked ^= true;
            captureImage.Rotate = menuItemRotate.Checked;
        }

        private void menuItemAiming_Click(object sender, EventArgs e)
        {
            // Toggle the check
            menuItemAiming.Checked ^= true;
            captureImage.UseAimLed = menuItemAiming.Checked;
        }
    }
}